\name{rmultireg}
\alias{rmultireg}
\concept{bayes}
\concept{multivariate regression}
\concept{simulation}

\title{ Draw from the Posterior of a Multivariate Regression }
\description{
  \code{rmultireg} draws from the posterior of a 
  Multivariate Regression model with a natural conjugate prior.
}
\usage{
rmultireg(Y, X, Bbar, A, nu, V, rep)
}

\arguments{
  \item{Y}{ n x m matrix of observations on m dep vars }
  \item{X}{ n x k matrix of observations on indep vars (supply intercept) }
  \item{Bbar}{ k x m matrix of prior mean of regression coefficients }
  \item{A}{ k x k Prior precision matrix }
  \item{nu}{ d.f. parameter for Sigma }
  \item{V}{ m x m pdf location parameter for prior on Sigma }
  \item{rep}{ number of posterior sample draws }
}
\details{
  Model: 
    \eqn{Y=XB+U}.  
    \eqn{cov(u_i) = Sigma}.  
    \eqn{B} is k x m matrix of coefficients. 
    \eqn{Sigma} is m x m covariance.

  Priors:  
    \eqn{beta} given \eqn{Sigma}  \eqn{\sim}{~} \eqn{N(betabar,Sigma (x) A^{-1})}. 
    \eqn{betabar=vec(Bbar)};  \eqn{beta = vec(B)} \cr
    \eqn{Sigma} \eqn{\sim}{~} IW(nu,V). 
}
\value{
  A list of the components of draws from the posterior
  \item{betadraw}{ draws of regression coefficient matrix }
  \item{Sigmadraw}{ draws of Sigma }
}
\references{ 
  Rossi, Allenby and McCulloch:\cr
  \emph{Bayesian Statistics and Marketing} Ch 2\cr
  \url{http://www.perossi.org/home/bsm-1}
}
\author{
  Chi Yau (based on R doc of \code{rmultireg} in \code{bayesm} by Peter Rossi)\cr
  \email{chi.yau@r-tutor.com}
}

\examples{
\dontrun{
library(rpud)

data.path <- file.path(path.package(package="rpud"), "runit/data")

# sample X
X <- read.table(
        file.path(data.path, "rmultireg-n100x2-x.txt"), 
        header=FALSE)
X <- as.matrix(X)

# sample Y
Y <- read.table(
        file.path(data.path, "rmultireg-n100x2-y.txt"), 
        header=FALSE)
Y <- as.matrix(Y)

# parameters
n <- nrow(X)
k <- ncol(X)
m <- ncol(Y)

Bbar <- matrix(c(1, 0, -1, 1),nrow=k,ncol=m)    # prior conjugate (normal) mean of B
A <- matrix(c(0.1, -0.05, -0.05, 0.1),nrow=k)   # prior conjugate (normal) precision of B
nu <- 3; V <- nu*diag(m)                        # prior Wishart params of Sigma

# mcmc params
R <- 2000

set.seed(66)
out <- rpud::rmultireg(Y, X, Bbar, A, nu, V, rep=R)

# true params
B <- matrix(c(1,2,-1,3),ncol=m)
Sigma <- matrix(c(1,.5,.5,1),ncol=m)

cat(" Beta draws ",fill=TRUE)
mat <- apply(out$betadraw,2,quantile,probs=c(.01,.05,.5,.95,.99))
mat <- rbind(as.vector(B),mat); rownames(mat)[1]="beta"
print(mat)

cat(" Sigma draws",fill=TRUE)
mat <- apply(out$Sigmadraw,2,quantile,probs=c(.01,.05,.5,.95,.99))
mat <- rbind(as.vector(Sigma),mat); rownames(mat)[1]="Sigma"
print(mat)
}}
\keyword{ regression }
